summaryrefslogtreecommitdiffstats
path: root/kommander/widgets
diff options
context:
space:
mode:
Diffstat (limited to 'kommander/widgets')
-rw-r--r--kommander/widgets/aboutdialog.cpp2
-rw-r--r--kommander/widgets/buttongroup.cpp4
-rw-r--r--kommander/widgets/checkbox.cpp4
-rw-r--r--kommander/widgets/combobox.cpp4
-rw-r--r--kommander/widgets/datepicker.cpp4
-rw-r--r--kommander/widgets/dialog.cpp12
-rw-r--r--kommander/widgets/execbutton.cpp10
-rw-r--r--kommander/widgets/fileselector.cpp8
-rw-r--r--kommander/widgets/groupbox.cpp4
-rw-r--r--kommander/widgets/label.cpp4
-rw-r--r--kommander/widgets/lineedit.cpp6
-rw-r--r--kommander/widgets/lineedit.h2
-rw-r--r--kommander/widgets/listbox.cpp4
-rw-r--r--kommander/widgets/pixmaplabel.cpp4
-rw-r--r--kommander/widgets/popupmenu.cpp6
-rw-r--r--kommander/widgets/progressbar.cpp8
-rw-r--r--kommander/widgets/radiobutton.cpp4
-rw-r--r--kommander/widgets/richtexteditor.cpp30
-rw-r--r--kommander/widgets/spinboxint.cpp4
-rw-r--r--kommander/widgets/table.cpp6
-rw-r--r--kommander/widgets/textedit.cpp6
-rw-r--r--kommander/widgets/toolbox.cpp4
-rw-r--r--kommander/widgets/treewidget.cpp10
23 files changed, 75 insertions, 75 deletions
diff --git a/kommander/widgets/aboutdialog.cpp b/kommander/widgets/aboutdialog.cpp
index 341bb5a4..097d0d22 100644
--- a/kommander/widgets/aboutdialog.cpp
+++ b/kommander/widgets/aboutdialog.cpp
@@ -21,7 +21,7 @@
#include <klocale.h>
#include <kstandarddirs.h>
-#include <textstream.h>
+#include <tqtextstream.h>
enum Functions {
FirstFunction = 159,
diff --git a/kommander/widgets/buttongroup.cpp b/kommander/widgets/buttongroup.cpp
index a110889a..e0c8b6ed 100644
--- a/kommander/widgets/buttongroup.cpp
+++ b/kommander/widgets/buttongroup.cpp
@@ -109,7 +109,7 @@ void ButtonGroup::contextMenuEvent( TQContextMenuEvent * e )
bool ButtonGroup::isFunctionSupported(int f)
{
- return f == DCOP::text || f == DCOP::checked || f == DCOP::setChecked || f == DCOP::geometry || f == DCOP::getBackgroundColor || f == DCOP::setBackgroundColor || (f >= FirstFunction && f <= LastFunction);
+ return f == DCOP::text || f == DCOP::checked || f == DCOP::setChecked || f == DCOP::tqgeometry || f == DCOP::getBackgroundColor || f == DCOP::setBackgroundColor || (f >= FirstFunction && f <= LastFunction);
}
@@ -133,7 +133,7 @@ TQString ButtonGroup::handleDCOP(int function, const TQStringList& args)
case BG_selectedId:
return TQString::number(this->selectedId() );
break;
- case DCOP::geometry:
+ case DCOP::tqgeometry:
{
TQString geo = TQString::number(this->x())+" "+TQString::number(this->y())+" "+TQString::number(this->width())+" "+TQString::number(this->height());
return geo;
diff --git a/kommander/widgets/checkbox.cpp b/kommander/widgets/checkbox.cpp
index 61ab0aff..696a9b2b 100644
--- a/kommander/widgets/checkbox.cpp
+++ b/kommander/widgets/checkbox.cpp
@@ -102,7 +102,7 @@ void CheckBox::showEvent(TQShowEvent* e)
bool CheckBox::isFunctionSupported(int f)
{
- return f == DCOP::text || f == DCOP::setText || f == DCOP::checked || f == DCOP::setChecked || f == DCOP::geometry || f == DCOP::getBackgroundColor || f == DCOP::setBackgroundColor;
+ return f == DCOP::text || f == DCOP::setText || f == DCOP::checked || f == DCOP::setChecked || f == DCOP::tqgeometry || f == DCOP::getBackgroundColor || f == DCOP::setBackgroundColor;
}
void CheckBox::contextMenuEvent( TQContextMenuEvent * e )
@@ -125,7 +125,7 @@ TQString CheckBox::handleDCOP(int function, const TQStringList& args)
case DCOP::setChecked:
setChecked(args[0] != "false" && args[0] != "0");
break;
- case DCOP::geometry:
+ case DCOP::tqgeometry:
{
TQString geo = TQString::number(this->x())+" "+TQString::number(this->y())+" "+TQString::number(this->width())+" "+TQString::number(this->height());
return geo;
diff --git a/kommander/widgets/combobox.cpp b/kommander/widgets/combobox.cpp
index d33a5147..844220c1 100644
--- a/kommander/widgets/combobox.cpp
+++ b/kommander/widgets/combobox.cpp
@@ -121,7 +121,7 @@ bool ComboBox::isFunctionSupported(int f)
return f == DCOP::text || f == DCOP::selection || f == DCOP::setSelection ||
f == DCOP::currentItem || f == DCOP::setCurrentItem || f == DCOP::item ||
f == DCOP::removeItem || f == DCOP::insertItem || f == DCOP::insertItems ||
- f == DCOP::addUniqueItem || f == DCOP::clear || f == DCOP::count || f == DCOP::setEditable || f == DCOP::geometry || f == DCOP::hasFocus || f == DCOP::getBackgroundColor || f == DCOP::setBackgroundColor || (f >= FirstFunction && f <= LastFunction);
+ f == DCOP::addUniqueItem || f == DCOP::clear || f == DCOP::count || f == DCOP::setEditable || f == DCOP::tqgeometry || f == DCOP::hasFocus || f == DCOP::getBackgroundColor || f == DCOP::setBackgroundColor || (f >= FirstFunction && f <= LastFunction);
}
TQString ComboBox::handleDCOP(int function, const TQStringList& args)
@@ -192,7 +192,7 @@ TQString ComboBox::handleDCOP(int function, const TQStringList& args)
case popupList:
TQComboBox::popup();
break;
- case DCOP::geometry:
+ case DCOP::tqgeometry:
{
TQString geo = TQString::number(this->x())+" "+TQString::number(this->y())+" "+TQString::number(this->width())+" "+TQString::number(this->height());
return geo;
diff --git a/kommander/widgets/datepicker.cpp b/kommander/widgets/datepicker.cpp
index 40b29de6..ffaebcae 100644
--- a/kommander/widgets/datepicker.cpp
+++ b/kommander/widgets/datepicker.cpp
@@ -101,7 +101,7 @@ void DatePicker::contextMenuEvent( TQContextMenuEvent * e )
bool DatePicker::isFunctionSupported(int f)
{
- return f == DCOP::text || f == DCOP::setText || f == DCOP::geometry || f == DCOP::hasFocus ;
+ return f == DCOP::text || f == DCOP::setText || f == DCOP::tqgeometry || f == DCOP::hasFocus ;
}
TQString DatePicker::handleDCOP(int function, const TQStringList& args)
@@ -112,7 +112,7 @@ TQString DatePicker::handleDCOP(int function, const TQStringList& args)
case DCOP::setText:
setDate(TQDate::fromString(args[0], Qt::ISODate));
break;
- case DCOP::geometry:
+ case DCOP::tqgeometry:
{
TQString geo = TQString::number(this->x())+" "+TQString::number(this->y())+" "+TQString::number(this->width())+" "+TQString::number(this->height());
return geo;
diff --git a/kommander/widgets/dialog.cpp b/kommander/widgets/dialog.cpp
index 21a3f7c1..15dd7e30 100644
--- a/kommander/widgets/dialog.cpp
+++ b/kommander/widgets/dialog.cpp
@@ -34,7 +34,7 @@
enum Functions {
FirstFunction = 185,
- D_focusWidget,
+ D_tqfocusWidget,
D_waitCursor,
D_restoreCursor,
LastFunction
@@ -53,7 +53,7 @@ Dialog::Dialog(TQWidget *a_parent, const char *a_name, bool a_modal, int a_flags
m_shebang = "#!/usr/bin/kmdr-executor";
m_firstShow = true;
KommanderPlugin::setDefaultGroup(Group::DCOP);
- KommanderPlugin::registerFunction(D_focusWidget, "focusWidget(TQString widget)", i18n("The name of the widget having focus"), 1);
+ KommanderPlugin::registerFunction(D_tqfocusWidget, "tqfocusWidget(TQString widget)", i18n("The name of the widget having focus"), 1);
KommanderPlugin::registerFunction(D_waitCursor, "waitCursor(TQString widget)", i18n("Set a wait cursor. CAUTION: if set more than once an equal number of calls to restore must be made to clear it."), 1);
KommanderPlugin::registerFunction(D_restoreCursor, "restoreCursor(TQString widget)", i18n("Restore normal curser. NOTE: must be called as many times as wait was."), 1);
}
@@ -193,7 +193,7 @@ void Dialog::contextMenuEvent( TQContextMenuEvent * e )
bool Dialog::isFunctionSupported(int f)
{
- return f == DCOP::text || f == DCOP::setText || f == DCOP::geometry || (f > FirstFunction && f < LastFunction);
+ return f == DCOP::text || f == DCOP::setText || f == DCOP::tqgeometry || (f > FirstFunction && f < LastFunction);
}
TQString Dialog::handleDCOP(int function, const TQStringList& args)
@@ -204,11 +204,11 @@ TQString Dialog::handleDCOP(int function, const TQStringList& args)
case DCOP::setText:
setWidgetText(args[0]);
break;
- case DCOP::geometry:
+ case DCOP::tqgeometry:
return TQString::number(this->x())+" "+TQString::number(this->y())+" "+TQString::number(this->width())+" "+TQString::number(this->height());
break;
- case D_focusWidget:
- return focusWidget()->name();
+ case D_tqfocusWidget:
+ return tqfocusWidget()->name();
break;
case D_waitCursor:
TQApplication::setOverrideCursor(TQCursor(TQt::WaitCursor));
diff --git a/kommander/widgets/execbutton.cpp b/kommander/widgets/execbutton.cpp
index 3d6df7c3..549b9678 100644
--- a/kommander/widgets/execbutton.cpp
+++ b/kommander/widgets/execbutton.cpp
@@ -113,7 +113,7 @@ void ExecButton::setWidgetText(const TQString& a_text)
void ExecButton::startProcess()
{
TQString at = evalAssociatedText().stripWhiteSpace();
- bool enabledStatus = isEnabled();
+ bool enabledtqStatus = isEnabled();
if (m_blockGUI != None)
setEnabled(false);
if (m_blockGUI == GUI)
@@ -128,7 +128,7 @@ void ExecButton::startProcess()
if (writeStdout())
cout << m_output << flush;
}
- setEnabled(enabledStatus);
+ setEnabled(enabledtqStatus);
}
@@ -180,7 +180,7 @@ void ExecButton::contextMenuEvent( TQContextMenuEvent * e )
bool ExecButton::isFunctionSupported(int f)
{
- return f == DCOP::text || f == DCOP::setText || f == DCOP::execute || f == DCOP::geometry || f == DCOP::getBackgroundColor || f == DCOP::setBackgroundColor || (f >= FirstFunction && f <= LastFunction);
+ return f == DCOP::text || f == DCOP::setText || f == DCOP::execute || f == DCOP::tqgeometry || f == DCOP::getBackgroundColor || f == DCOP::setBackgroundColor || (f >= FirstFunction && f <= LastFunction);
}
TQString ExecButton::handleDCOP(int function, const TQStringList& args)
@@ -202,7 +202,7 @@ TQString ExecButton::handleDCOP(int function, const TQStringList& args)
break;
case EB_setPopup:
{
- TQWidgetList *list = TQApplication::allWidgets();
+ TQWidgetList *list = TQApplication::tqallWidgets();
TQWidgetListIt it( *list );
TQWidget * w;
while ( (w=it.current()) != 0 ) { // for each widget...
@@ -215,7 +215,7 @@ TQString ExecButton::handleDCOP(int function, const TQStringList& args)
}
break;
}
- case DCOP::geometry:
+ case DCOP::tqgeometry:
{
TQString geo = TQString::number(this->x())+" "+TQString::number(this->y())+" "+TQString::number(this->width())+" "+TQString::number(this->height());
return geo;
diff --git a/kommander/widgets/fileselector.cpp b/kommander/widgets/fileselector.cpp
index a1f08ec5..51afa92a 100644
--- a/kommander/widgets/fileselector.cpp
+++ b/kommander/widgets/fileselector.cpp
@@ -27,7 +27,7 @@
#include <tqwidget.h>
#include <tqstringlist.h>
#include <tqevent.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqsizepolicy.h>
/* OTHER INCLUDES */
@@ -50,9 +50,9 @@ FileSelector::FileSelector(TQWidget * a_parent, const char *a_name)
m_boxLayout->addWidget(m_lineEdit);
m_boxLayout->addWidget(m_selectButton);
- setSizePolicy(m_lineEdit->sizePolicy());
- m_lineEdit->setSizePolicy(TQSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Expanding));
- m_selectButton->setSizePolicy(TQSizePolicy(TQSizePolicy::Minimum, TQSizePolicy::Expanding));
+ tqsetSizePolicy(m_lineEdit->sizePolicy());
+ m_lineEdit->tqsetSizePolicy(TQSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Expanding));
+ m_selectButton->tqsetSizePolicy(TQSizePolicy(TQSizePolicy::Minimum, TQSizePolicy::Expanding));
connect(m_selectButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(makeSelection()));
diff --git a/kommander/widgets/groupbox.cpp b/kommander/widgets/groupbox.cpp
index 7d4f43e8..aef8042d 100644
--- a/kommander/widgets/groupbox.cpp
+++ b/kommander/widgets/groupbox.cpp
@@ -108,7 +108,7 @@ void GroupBox::contextMenuEvent( TQContextMenuEvent * e )
bool GroupBox::isFunctionSupported(int f)
{
- return f == DCOP::text || f == DCOP::setText || f == DCOP::geometry || f == DCOP::getBackgroundColor || f == DCOP::setBackgroundColor;
+ return f == DCOP::text || f == DCOP::setText || f == DCOP::tqgeometry || f == DCOP::getBackgroundColor || f == DCOP::setBackgroundColor;
// || (f >= FirstFunction && f <= LastFunction);
}
@@ -126,7 +126,7 @@ TQString GroupBox::handleDCOP(int function, const TQStringList& args)
case DCOP::setText:
setTitle(args[0]);
break;
- case DCOP::geometry:
+ case DCOP::tqgeometry:
{
TQString geo = TQString::number(this->x())+" "+TQString::number(this->y())+" "+TQString::number(this->width())+" "+TQString::number(this->height());
return geo;
diff --git a/kommander/widgets/label.cpp b/kommander/widgets/label.cpp
index 2f4b0dea..6c6eb787 100644
--- a/kommander/widgets/label.cpp
+++ b/kommander/widgets/label.cpp
@@ -88,7 +88,7 @@ void Label::showEvent(TQShowEvent *e)
bool Label::isFunctionSupported(int f)
{
- return f == DCOP::text || f == DCOP::setText || f == DCOP::clear || f == DCOP::geometry || f == DCOP::getBackgroundColor || f == DCOP::setBackgroundColor;
+ return f == DCOP::text || f == DCOP::setText || f == DCOP::clear || f == DCOP::tqgeometry || f == DCOP::getBackgroundColor || f == DCOP::setBackgroundColor;
}
TQString Label::handleDCOP(int function, const TQStringList& args)
@@ -102,7 +102,7 @@ TQString Label::handleDCOP(int function, const TQStringList& args)
case DCOP::clear:
setWidgetText("");
break;
- case DCOP::geometry:
+ case DCOP::tqgeometry:
{
TQString geo = TQString::number(this->x())+" "+TQString::number(this->y())+" "+TQString::number(this->width())+" "+TQString::number(this->height());
return geo;
diff --git a/kommander/widgets/lineedit.cpp b/kommander/widgets/lineedit.cpp
index 991f64b0..07a852b7 100644
--- a/kommander/widgets/lineedit.cpp
+++ b/kommander/widgets/lineedit.cpp
@@ -15,7 +15,7 @@
***************************************************************************/
/* QT INCLUDES */
-#include <layout.h>
+#include <tqlayout.h>
#include <tqevent.h>
/* OTHER INCLUDES */
@@ -124,7 +124,7 @@ void LineEdit::contextMenuEvent( TQContextMenuEvent * e )
bool LineEdit::isFunctionSupported(int f)
{
return f == DCOP::text || f == DCOP::setText || f == DCOP::selection || f == DCOP::setSelection ||
- f == DCOP::clear || f == DCOP::setEditable || f == DCOP::geometry || f == DCOP::hasFocus || f == DCOP::getBackgroundColor || f == DCOP::setBackgroundColor || f == DCOP::isModified || (f >= FirstFunction && f <= LastFunction) ;
+ f == DCOP::clear || f == DCOP::setEditable || f == DCOP::tqgeometry || f == DCOP::hasFocus || f == DCOP::getBackgroundColor || f == DCOP::setBackgroundColor || f == DCOP::isModified || (f >= FirstFunction && f <= LastFunction) ;
}
TQString LineEdit::handleDCOP(int function, const TQStringList& args)
@@ -146,7 +146,7 @@ TQString LineEdit::handleDCOP(int function, const TQStringList& args)
case DCOP::setEditable:
setReadOnly(args[0] == "false" || args[0] == "0");
break;
- case DCOP::geometry:
+ case DCOP::tqgeometry:
{
TQString geo = TQString::number(this->x())+" "+TQString::number(this->y())+" "+TQString::number(this->width())+" "+TQString::number(this->height());
return geo;
diff --git a/kommander/widgets/lineedit.h b/kommander/widgets/lineedit.h
index 784c9d9b..80c5e8b9 100644
--- a/kommander/widgets/lineedit.h
+++ b/kommander/widgets/lineedit.h
@@ -21,7 +21,7 @@
#include <klineedit.h>
/* QT INCLUDES */
-#include <textedit.h>
+#include <tqtextedit.h>
#include <tqstringlist.h>
#include <tqstring.h>
diff --git a/kommander/widgets/listbox.cpp b/kommander/widgets/listbox.cpp
index 5f9fdf02..8612dea2 100644
--- a/kommander/widgets/listbox.cpp
+++ b/kommander/widgets/listbox.cpp
@@ -96,7 +96,7 @@ bool ListBox::isFunctionSupported(int f)
return f == DCOP::text || f == DCOP::setText || f == DCOP::selection || f == DCOP::setSelection ||
f == DCOP::insertItems || f == DCOP::insertItem || f == DCOP::removeItem || f == DCOP::clear ||
f == DCOP::currentItem || f == DCOP::setCurrentItem || f == DCOP::item || f == DCOP::addUniqueItem ||
- f == DCOP::findItem || f == DCOP::setPixmap || f == DCOP::count || f == DCOP::geometry || f == DCOP::hasFocus || f == DCOP::getBackgroundColor || f == DCOP::setBackgroundColor;
+ f == DCOP::findItem || f == DCOP::setPixmap || f == DCOP::count || f == DCOP::tqgeometry || f == DCOP::hasFocus || f == DCOP::getBackgroundColor || f == DCOP::setBackgroundColor;
}
void ListBox::contextMenuEvent( TQContextMenuEvent * e )
@@ -197,7 +197,7 @@ TQString ListBox::handleDCOP(int function, const TQStringList& args)
strings += item(i)->text();
return strings.join("\n");
}
- case DCOP::geometry:
+ case DCOP::tqgeometry:
{
TQString geo = TQString::number(this->x())+" "+TQString::number(this->y())+" "+TQString::number(this->width())+" "+TQString::number(this->height());
return geo;
diff --git a/kommander/widgets/pixmaplabel.cpp b/kommander/widgets/pixmaplabel.cpp
index 4ccf921b..4bac254e 100644
--- a/kommander/widgets/pixmaplabel.cpp
+++ b/kommander/widgets/pixmaplabel.cpp
@@ -103,7 +103,7 @@ void PixmapLabel::contextMenuEvent( TQContextMenuEvent * e )
bool PixmapLabel::isFunctionSupported(int f)
{
- return f == DCOP::text || f == DCOP::setText || f == DCOP::clear || f == DCOP::geometry;
+ return f == DCOP::text || f == DCOP::setText || f == DCOP::clear || f == DCOP::tqgeometry;
}
TQString PixmapLabel::handleDCOP(int function, const TQStringList& args)
@@ -117,7 +117,7 @@ TQString PixmapLabel::handleDCOP(int function, const TQStringList& args)
break;
case DCOP::text:
return text();
- case DCOP::geometry:
+ case DCOP::tqgeometry:
{
TQString geo = TQString::number(this->x())+" "+TQString::number(this->y())+" "+TQString::number(this->width())+" "+TQString::number(this->height());
return geo;
diff --git a/kommander/widgets/popupmenu.cpp b/kommander/widgets/popupmenu.cpp
index 65bbdc7a..ab52aac6 100644
--- a/kommander/widgets/popupmenu.cpp
+++ b/kommander/widgets/popupmenu.cpp
@@ -114,7 +114,7 @@ void PopupMenu::popup(int x, int y)
void PopupMenu::slotMenuItemActivated(int id)
{
TQString widget = m_associations[id];
- KommanderWidget::evalAssociatedText(TQString("#!kommander\n%1.execute(%2)").arg(widget).arg(id));
+ KommanderWidget::evalAssociatedText(TQString("#!kommander\n%1.execute(%2)").tqarg(widget).tqarg(id));
}
void PopupMenu::populate()
@@ -138,7 +138,7 @@ TQString PopupMenu::insertSubmenu(const TQString& title, const TQString &menuWid
bool PopupMenu::isFunctionSupported(int f)
{
- return f == DCOP::clear || f == DCOP::execute || f == DCOP::item || (f >= INSERTMENUITEM && f <= LAST_FUNCTION) || f == DCOP::count || f == DCOP::geometry;
+ return f == DCOP::clear || f == DCOP::execute || f == DCOP::item || (f >= INSERTMENUITEM && f <= LAST_FUNCTION) || f == DCOP::count || f == DCOP::tqgeometry;
}
TQString PopupMenu::handleDCOP(int function, const TQStringList& args)
@@ -229,7 +229,7 @@ TQString PopupMenu::handleDCOP(int function, const TQStringList& args)
case DCOP::count:
return TQString::number(m_menu->count());
break;
- case DCOP::geometry:
+ case DCOP::tqgeometry:
{
TQString geo = TQString::number(this->x())+" "+TQString::number(this->y())+" "+TQString::number(this->width())+" "+TQString::number(this->height());
return geo;
diff --git a/kommander/widgets/progressbar.cpp b/kommander/widgets/progressbar.cpp
index 8d2a51e2..f78ce62c 100644
--- a/kommander/widgets/progressbar.cpp
+++ b/kommander/widgets/progressbar.cpp
@@ -94,7 +94,7 @@ void ProgressBar::showEvent(TQShowEvent *e)
bool ProgressBar::isFunctionSupported(int f)
{
- return f == DCOP::text || f == DCOP::setText || f == DCOP::clear || f == DCOP::setMaximum || f == DCOP::geometry || (f > FirstFunction && f < LastFunction);
+ return f == DCOP::text || f == DCOP::setText || f == DCOP::clear || f == DCOP::setMaximum || f == DCOP::tqgeometry || (f > FirstFunction && f < LastFunction);
}
TQString ProgressBar::handleDCOP(int function, const TQStringList& args)
@@ -111,7 +111,7 @@ TQString ProgressBar::handleDCOP(int function, const TQStringList& args)
case DCOP::setMaximum:
setTotalSteps(args[0].toUInt());
break;
- case DCOP::geometry:
+ case DCOP::tqgeometry:
{
TQString geo = TQString::number(this->x())+" "+TQString::number(this->y())+" "+TQString::number(this->width())+" "+TQString::number(this->height());
return geo;
@@ -123,7 +123,7 @@ TQString ProgressBar::handleDCOP(int function, const TQStringList& args)
color.setNamedColor(args[0]);
TQPalette p = this->palette();
p.setColor(TQPalette::Active, TQColorGroup::Highlight, color);
- this->setPalette( p, TRUE );
+ this->tqsetPalette( p, TRUE );
break;
}
case PB_setHightlightTextColor:
@@ -132,7 +132,7 @@ TQString ProgressBar::handleDCOP(int function, const TQStringList& args)
color.setNamedColor(args[0]);
TQPalette p = this->palette();
p.setColor(TQPalette::Active, TQColorGroup::HighlightedText, color);
- this->setPalette( p, TRUE );
+ this->tqsetPalette( p, TRUE );
break;
}
default:
diff --git a/kommander/widgets/radiobutton.cpp b/kommander/widgets/radiobutton.cpp
index d6306c80..317263e4 100644
--- a/kommander/widgets/radiobutton.cpp
+++ b/kommander/widgets/radiobutton.cpp
@@ -101,7 +101,7 @@ void RadioButton::contextMenuEvent( TQContextMenuEvent * e )
bool RadioButton::isFunctionSupported(int f)
{
- return f == DCOP::text || f == DCOP::setText || f == DCOP::setChecked || f == DCOP::checked || f == DCOP::geometry || f == DCOP::getBackgroundColor || f == DCOP::setBackgroundColor;
+ return f == DCOP::text || f == DCOP::setText || f == DCOP::setChecked || f == DCOP::checked || f == DCOP::tqgeometry || f == DCOP::getBackgroundColor || f == DCOP::setBackgroundColor;
}
TQString RadioButton::handleDCOP(int function, const TQStringList& args)
@@ -117,7 +117,7 @@ TQString RadioButton::handleDCOP(int function, const TQStringList& args)
break;
case DCOP::checked:
return TQString::number(isOn());
- case DCOP::geometry:
+ case DCOP::tqgeometry:
{
TQString geo = TQString::number(this->x())+" "+TQString::number(this->y())+" "+TQString::number(this->width())+" "+TQString::number(this->height());
return geo;
diff --git a/kommander/widgets/spinboxint.cpp b/kommander/widgets/spinboxint.cpp
index 72991376..cc264f34 100644
--- a/kommander/widgets/spinboxint.cpp
+++ b/kommander/widgets/spinboxint.cpp
@@ -101,7 +101,7 @@ void SpinBoxInt::focusInEvent( TQFocusEvent * e)
bool SpinBoxInt::isFunctionSupported(int f)
{
- return f == DCOP::text || f == DCOP::setText || f == DCOP::setMaximum || f == DCOP::geometry|| f == DCOP::getBackgroundColor || f == DCOP::setBackgroundColor;
+ return f == DCOP::text || f == DCOP::setText || f == DCOP::setMaximum || f == DCOP::tqgeometry|| f == DCOP::getBackgroundColor || f == DCOP::setBackgroundColor;
}
TQString SpinBoxInt::handleDCOP(int function, const TQStringList& args)
@@ -115,7 +115,7 @@ TQString SpinBoxInt::handleDCOP(int function, const TQStringList& args)
case DCOP::setMaximum:
setMaxValue(args[0].toUInt());
break;
- case DCOP::geometry:
+ case DCOP::tqgeometry:
{
TQString geo = TQString::number(this->x())+" "+TQString::number(this->y())+" "+TQString::number(this->width())+" "+TQString::number(this->height());
return geo;
diff --git a/kommander/widgets/table.cpp b/kommander/widgets/table.cpp
index 862bb17a..7d974994 100644
--- a/kommander/widgets/table.cpp
+++ b/kommander/widgets/table.cpp
@@ -114,7 +114,7 @@ void Table::setWidgetText(const TQString&)
TQString Table::selectedArea()
{
TQTableSelection sel = selection(currentSelection());
- return TQString("%1,%2,%3,%4").arg(sel.topRow()).arg(sel.leftCol()).arg(sel.bottomRow()).arg(sel.rightCol());
+ return TQString("%1,%2,%3,%4").tqarg(sel.topRow()).tqarg(sel.leftCol()).tqarg(sel.bottomRow()).tqarg(sel.rightCol());
}
@@ -123,7 +123,7 @@ bool Table::isFunctionSupported(int f)
return f == DCOP::currentColumn || f == DCOP::currentRow || f == DCOP::insertColumn ||
f == DCOP::insertRow || f == DCOP::cellText || f == DCOP::setCellText || f == DCOP::setCellWidget || f == DCOP::cellWidget || f == DCOP::columnCount ||
f == DCOP::removeRow || f == DCOP::removeColumn || f == DCOP::setColumnCaption ||
- f == DCOP::setRowCaption || f == DCOP::text || f == DCOP::setText || f == DCOP::selection || f == DCOP::geometry || f == DCOP::hasFocus || f == DCOP::getBackgroundColor || f == DCOP::setBackgroundColor || (f >= FirstFunction && f <= LastFunction);
+ f == DCOP::setRowCaption || f == DCOP::text || f == DCOP::setText || f == DCOP::selection || f == DCOP::tqgeometry || f == DCOP::hasFocus || f == DCOP::getBackgroundColor || f == DCOP::setBackgroundColor || (f >= FirstFunction && f <= LastFunction);
}
void Table::setCellWidget(int row, int col, const TQString & _widgetName)
@@ -354,7 +354,7 @@ TQString Table::handleDCOP(int function, const TQStringList& args)
return "No row at index "+args[0];
break;
}
- case DCOP::geometry:
+ case DCOP::tqgeometry:
{
TQString geo = TQString::number(this->x())+" "+TQString::number(this->y())+" "+TQString::number(this->width())+" "+TQString::number(this->height());
return geo;
diff --git a/kommander/widgets/textedit.cpp b/kommander/widgets/textedit.cpp
index 78c00c08..2c210696 100644
--- a/kommander/widgets/textedit.cpp
+++ b/kommander/widgets/textedit.cpp
@@ -16,7 +16,7 @@
***************************************************************************/
/* QT INCLUDES */
-#include <layout.h>
+#include <tqlayout.h>
#include <tqlineedit.h>
#include <tqstringlist.h>
#include <tqevent.h>
@@ -143,7 +143,7 @@ void TextEdit::contextMenuEvent( TQContextMenuEvent * e )
bool TextEdit::isFunctionSupported(int f)
{
- return f == DCOP::text || f == DCOP::setText || f == DCOP::selection || f == DCOP::setSelection || f == DCOP::clear || f == DCOP::setEditable || f == DCOP::geometry || f == DCOP::hasFocus || f == DCOP::getBackgroundColor || f == DCOP::setBackgroundColor || f == DCOP::isModified || (f >= FirstFunction && f <= LastFunction);
+ return f == DCOP::text || f == DCOP::setText || f == DCOP::selection || f == DCOP::setSelection || f == DCOP::clear || f == DCOP::setEditable || f == DCOP::tqgeometry || f == DCOP::hasFocus || f == DCOP::getBackgroundColor || f == DCOP::setBackgroundColor || f == DCOP::isModified || (f >= FirstFunction && f <= LastFunction);
}
TQString TextEdit::handleDCOP(int function, const TQStringList& args)
@@ -210,7 +210,7 @@ TQString TextEdit::handleDCOP(int function, const TQStringList& args)
case TE_VAnormalScript:
TQTextEdit::setVerticalAlignment(AlignNormal);
break;
- case DCOP::geometry:
+ case DCOP::tqgeometry:
{
TQString geo = TQString::number(this->x())+" "+TQString::number(this->y())+" "+TQString::number(this->width())+" "+TQString::number(this->height());
return geo;
diff --git a/kommander/widgets/toolbox.cpp b/kommander/widgets/toolbox.cpp
index c2d37ff4..a3249bd0 100644
--- a/kommander/widgets/toolbox.cpp
+++ b/kommander/widgets/toolbox.cpp
@@ -121,7 +121,7 @@ void ToolBox::contextMenuEvent( TQContextMenuEvent * e )
bool ToolBox::isFunctionSupported(int f)
{
- return f == DCOP::count || f == DCOP::geometry || (f >= FIRST_FUNCTION && f <= LAST_FUNCTION) ;
+ return f == DCOP::count || f == DCOP::tqgeometry || (f >= FIRST_FUNCTION && f <= LAST_FUNCTION) ;
}
TQString ToolBox::handleDCOP(int function, const TQStringList& args)
@@ -176,7 +176,7 @@ TQString ToolBox::handleDCOP(int function, const TQStringList& args)
}
case DCOP::count:
return TQString::number(count());
- case DCOP::geometry:
+ case DCOP::tqgeometry:
{
TQString geo = TQString::number(this->x())+" "+TQString::number(this->y())+" "+TQString::number(this->width())+" "+TQString::number(this->height());
return geo;
diff --git a/kommander/widgets/treewidget.cpp b/kommander/widgets/treewidget.cpp
index 914d6b7c..c77d4b8e 100644
--- a/kommander/widgets/treewidget.cpp
+++ b/kommander/widgets/treewidget.cpp
@@ -208,8 +208,8 @@ TQString TreeWidget::itemsText()
if (path.isEmpty())
items.append(itemText(it.current()));
else
- items.append(TQString("%1%2%3").arg(path).arg(m_pathSeparator)
- .arg(itemText(it.current())));
+ items.append(TQString("%1%2%3").tqarg(path).tqarg(m_pathSeparator)
+ .tqarg(itemText(it.current())));
++it;
}
return items.join("\n");
@@ -307,7 +307,7 @@ bool TreeWidget::isFunctionSupported(int f)
return f == DCOP::insertItem || f == DCOP::text || f == DCOP::setText || f == DCOP::insertItems ||
f == DCOP::selection || f == DCOP::setSelection || f == DCOP::clear || f == DCOP::removeItem ||
f == DCOP::currentItem || f == DCOP::setCurrentItem || f == DCOP::findItem || f == DCOP::item ||
- f == DCOP::itemPath || f == DCOP::itemDepth || f == DCOP::setPixmap || f == DCOP::setColumnCaption || f == DCOP::removeColumn || f == DCOP::columnCount || f == DCOP::geometry || f == DCOP::hasFocus || f == DCOP::getBackgroundColor || f == DCOP::setBackgroundColor || (f > FirstFunction && f < LastFunction) || (f >= TW_FUNCTION && f <= TW_LAST_FUNCTION);
+ f == DCOP::itemPath || f == DCOP::itemDepth || f == DCOP::setPixmap || f == DCOP::setColumnCaption || f == DCOP::removeColumn || f == DCOP::columnCount || f == DCOP::tqgeometry || f == DCOP::hasFocus || f == DCOP::getBackgroundColor || f == DCOP::setBackgroundColor || (f > FirstFunction && f < LastFunction) || (f >= TW_FUNCTION && f <= TW_LAST_FUNCTION);
}
TQString TreeWidget::handleDCOP(int function, const TQStringList& args)
@@ -342,7 +342,7 @@ TQString TreeWidget::handleDCOP(int function, const TQStringList& args)
{
if (it.current()->isSelected())
{
- selection.append(TQString("%1\n").arg(itemToIndexSafe(it.current())));
+ selection.append(TQString("%1\n").tqarg(itemToIndexSafe(it.current())));
}
++it;
}
@@ -494,7 +494,7 @@ TQString TreeWidget::handleDCOP(int function, const TQStringList& args)
case TW_childCount:
return TQString::number(childCount());
break;
- case DCOP::geometry:
+ case DCOP::tqgeometry:
{
TQString geo = TQString::number(this->x())+" "+TQString::number(this->y())+" "+TQString::number(this->width())+" "+TQString::number(this->height());
return geo;
diff --git a/kommander/widgets/richtexteditor.cpp b/kommander/widgets/richtexteditor.cpp
index 04014c17..5c6c530c 100644
--- a/kommander/widgets/richtexteditor.cpp
+++ b/kommander/widgets/richtexteditor.cpp
@@ -17,12 +17,12 @@
#include <klocale.h>
/* QT INCLUDES */
-#include <layout.h>
+#include <tqlayout.h>
#include <tqevent.h>
-#include <textedit.h>
+#include <tqtextedit.h>
#include <tqframe.h>
#include <tqwidget.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqtoolbutton.h>
#include <tqpixmap.h>
#include <tqhbuttongroup.h>
@@ -61,11 +61,11 @@ RichTextEditor::RichTextEditor(TQWidget *a_parent, const char *a_name)
m_textedit = new TQTextEdit(this, "editor");
m_textedit->setTextFormat(RichText);
- // layout the widgets
- TQVBoxLayout *layout = new TQVBoxLayout(this);
- layout->addWidget(m_toolbar);
- layout->addWidget(m_textedit);
- layout->setSpacing(1);
+ // tqlayout the widgets
+ TQVBoxLayout *tqlayout = new TQVBoxLayout(this);
+ tqlayout->addWidget(m_toolbar);
+ tqlayout->addWidget(m_textedit);
+ tqlayout->setSpacing(1);
// setup buttons
TQHBoxLayout *tbLayout = new TQHBoxLayout(m_toolbar);
@@ -182,11 +182,11 @@ void RichTextEditor::textAlign(int a_id)
{
TQToolButton *b = (TQToolButton *)m_alignGroup->find(a_id);
if(b == m_buttonTextLeft)
- m_textedit->setAlignment(TQt::AlignLeft);
+ m_textedit->tqsetAlignment(TQt::AlignLeft);
else if(b == m_buttonTextCenter)
- m_textedit->setAlignment(TQt::AlignCenter);
+ m_textedit->tqsetAlignment(TQt::AlignCenter);
else if(b == m_buttonTextRight)
- m_textedit->setAlignment(TQt::AlignRight);
+ m_textedit->tqsetAlignment(TQt::AlignRight);
}
void RichTextEditor::fontChanged(const TQFont &a_font)
@@ -196,13 +196,13 @@ void RichTextEditor::fontChanged(const TQFont &a_font)
m_buttonTextUnder->setOn(a_font.underline());
}
-void RichTextEditor::alignmentChanged(int a_alignment)
+void RichTextEditor::alignmentChanged(int a_tqalignment)
{
- if((a_alignment == AlignAuto) || (a_alignment & AlignLeft))
+ if((a_tqalignment == AlignAuto) || (a_tqalignment & AlignLeft))
m_buttonTextLeft->setOn(true);
- else if(a_alignment & AlignHCenter)
+ else if(a_tqalignment & AlignHCenter)
m_buttonTextCenter->setOn(true);
- else if(a_alignment & AlignRight)
+ else if(a_tqalignment & AlignRight)
m_buttonTextRight->setOn(true);
}